@@ -15,6 +15,6 @@ class SendRCKeyCommand(CommandBase):
 
         requestObj = [keyName]
 
-        result = self.executeCommand(requestObj, "Could not execute command")
+        result = self.executeCommand(requestObj)
 
         return SendRCKeyResult(result, "SendRCKey was successful", "SendRCKey failed")
